%define upstream_name    Memoize
%define upstream_version 1.17

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1

Summary:    Automatically cache results of functions
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module//%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Scalar::Util) >= 1.110.0
BuildRequires: perl(Test::More)
BuildArch:  noarch

%description
`Memoizing' a function makes it faster by trading space for time. It does
this by caching the return values of the function in a table. If you call
the function again with the same arguments, 'memoize' jumps in and gives
you the value out of the table, instead of letting the function compute the
value all over again.

Here is an extreme example. Consider the Fibonacci sequence, defined by the
following function:

	# Compute Fibonacci numbers
	sub fib {
	  my $n = shift;
	  return $n if $n < 2;
	  fib($n-1) + fib($n-2);
	}

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README TODO
%{_mandir}/man3/*
%perl_vendorlib/*

%changelog
* Fri Jan 24 2025 tv <tv> 1.170.0-1.mga10
+ Revision: 2141582
- update to 1.17

* Fri Feb 03 2023 tv <tv> 1.160.0-1.mga9
+ Revision: 1937861
- update to 1.16

* Thu Oct 27 2022 tv <tv> 1.150.0-1.mga9
+ Revision: 1899749
- update to 1.15

* Thu Oct 20 2022 tv <tv> 1.140.0-1.mga9
+ Revision: 1897927
- update to 1.14

* Mon Sep 05 2022 tv <tv> 1.130.0-1.mga9
+ Revision: 1884213
- update to 1.13

* Sat Aug 13 2022 tv <tv> 1.100.0-1.mga9
+ Revision: 1877444
- update to 1.10

* Wed Aug 03 2022 tv <tv> 1.90.0-1.mga9
+ Revision: 1874909
- update to 1.09

* Fri Jul 29 2022 tv <tv> 1.80.0-1.mga9
+ Revision: 1872836
- update to 1.08

* Tue Jul 26 2022 tv <tv> 1.50.0-1.mga9
+ Revision: 1872055
- update to 1.05

* Sun Mar 20 2022 umeabot <umeabot> 1.30.0-14.mga9
+ Revision: 1804467
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 1.30.0-13.mga8
+ Revision: 1495591
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Wed Sep 19 2018 umeabot <umeabot> 1.30.0-12.mga7
+ Revision: 1269249
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 1.30.0-11.mga6
+ Revision: 1029875
- Rebuild for perl 5.22.2

* Sat Feb 06 2016 umeabot <umeabot> 1.30.0-10.mga6
+ Revision: 941936
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.30.0-9.mga5
+ Revision: 750311
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.30.0-8.mga5
+ Revision: 685391
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.30.0-7.mga4
+ Revision: 522785
- Mageia 4 Mass Rebuild

* Wed Mar 27 2013 jquelin <jquelin> 1.30.0-6.mga3
+ Revision: 405508
- perl 5.16.3 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.30.0-5.mga3
+ Revision: 369690
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 07 2012 jquelin <jquelin> 1.30.0-4.mga3
+ Revision: 315525
- perl 5.16.2 rebuild

* Mon Sep 17 2012 jquelin <jquelin> 1.30.0-3.mga3
+ Revision: 294851
- perl 5.16.1 rebuild

* Mon Aug 27 2012 jquelin <jquelin> 1.30.0-2.mga3
+ Revision: 284591
- perl 5.16.1 rebuild

* Sat Jun 09 2012 jquelin <jquelin> 1.30.0-1.mga3
+ Revision: 258919
- imported package perl-Memoize

